

# Format for the SNP schemes

 	

| Field         | Description            |
| ------------- | ---------------------- |
| lineage       | tag of a given lineage |
| position      |                        |
| gene_coord    |                        |
| allele_change |                        |
| codon_number  |                        |
| codon_change  |                        |
| aa_change     |                        |
| locus_id      |                        |
| gene_name     |                        |
|               |                        |